Frontmatter class
L1 skill metadata parsed from SKILL.md frontmatter.
- Implemented types
Constructors
Properties
- allowedTools → String?
-
final
- compatibility → String?
-
final
- description → String
-
final
-
extraFields
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- license → String?
-
final
-
metadata
→ Map<
String, String> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
{bool byAlias = false}) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited