Resources class

L3 skill resources loaded from references/assets/scripts directories.

Constructors

Resources({Map<String, String>? references, Map<String, String>? assets, Map<String, Script>? scripts})

Properties

assets Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
references Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scripts Map<String, Script>
final

Methods

getAsset(String assetId) String?
getReference(String referenceId) String?
getScript(String scriptId) Script?
listAssets() List<String>
listReferences() List<String>
listScripts() List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited