Skill class

Complete skill representation with metadata, instructions, and resources.

Implemented types

Constructors

Skill({Frontmatter? frontmatter, String? name, String? description, String instructions = '', Resources? resources, String version = '0.1.0', String? license, String? compatibility, String? allowedTools, Map<String, String>? metadata})
Creates a complete skill object.

Properties

description String
Skill description from frontmatter.
no setteroverride
frontmatter Frontmatter
Parsed SKILL.md frontmatter metadata.
final
hashCode int
The hash code for this object.
no setterinherited
instructions String
Markdown body instructions from SKILL.md.
final
name String
Skill name from frontmatter.
no setteroverride
resources Resources
Associated references/assets/scripts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
Optional skill version string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited