CallCodeEvent class

Request to execute code.

Inheritance

Constructors

CallCodeEvent(Object code)
Creates a code-call event.
const

Properties

code Object
Provider-specific executable-code payload.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type EventType
Category of this structured event.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited