ContentEvent class

User-visible text content.

Inheritance

Constructors

ContentEvent(String content)
Creates a content event.
const

Properties

content String
Text content.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type EventType
Category of this structured event.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited