ErrorEvent class

Runtime error event.

Inheritance

Constructors

ErrorEvent({required String message, String? code, Object? error})
Creates an error event.

Properties

code String?
Optional provider/runtime error code.
final
error Object
Error object matching the upstream structured-event shape.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Error message shown to callers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type EventType
Category of this structured event.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited