EventType enum

Categories emitted by toStructuredEvents.

Inheritance
Available extensions

Values

thought → const EventType

Model reasoning text.

const EventType('thought')
content → const EventType

User-visible text content.

const EventType('content')
toolCall → const EventType

Model-requested tool call.

const EventType('tool_call')
toolResult → const EventType

Tool execution result.

const EventType('tool_result')
callCode → const EventType

Model-requested code execution.

const EventType('call_code')
codeResult → const EventType

Code execution result.

const EventType('code_result')
error → const EventType

Runtime error.

const EventType('error')
activity → const EventType

Generic activity/status update.

const EventType('activity')
toolConfirmation → const EventType

Request for user confirmation of one or more tool calls.

const EventType('tool_confirmation')
finished → const EventType

Final response marker for the current turn.

const EventType('finished')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
Stable wire name matching the upstream JS event type values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EventType>
A constant List of the values in this enum, in order of their declaration.