FileData class

File reference payload attached to a Part.

Constructors

FileData({required String fileUri, String? mimeType, String? displayName})
Creates file reference data.

Properties

displayName String?
Optional display label.
getter/setter pair
fileUri String
URI for the remote or local file resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
Optional MIME type for the file.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? fileUri, Object? mimeType = _sentinel, Object? displayName = _sentinel}) FileData
Returns a copy of this file payload with optional overrides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited