FunctionCall class

Function-call payload emitted by model responses.

Constructors

FunctionCall({required String name, JsonMap? args, String? id, List<Map<String, Object?>>? partialArgs, bool? willContinue})
Creates a function-call payload.

Properties

args JsonMap
Function arguments payload.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Optional tool-call identifier.
getter/setter pair
name String
Function name requested by the model.
getter/setter pair
partialArgs List<Map<String, Object?>>?
Optional partial argument deltas from streaming calls.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
willContinue bool?
Whether additional streaming call chunks are expected.
getter/setter pair

Methods

copyWith({String? name, JsonMap? args, Object? id = _sentinel, Object? partialArgs = _sentinel, Object? willContinue = _sentinel}) FunctionCall
Returns a copy of this function-call payload.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited