FunctionDeclaration class

Function-calling declaration exposed to the model.

Constructors

FunctionDeclaration({required String name, String description = '', JsonMap? parameters})
Creates a function declaration.

Properties

description String
The function description shown to the model.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
The function name.
getter/setter pair
parameters JsonMap
JSON schema parameters for the function.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? description, JsonMap? parameters}) FunctionDeclaration
Returns a copy of this declaration with optional overrides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited