GetSessionConfig class

Options for narrowing session retrieval results.

Constructors

GetSessionConfig({int? numRecentEvents, double? afterTimestamp})
Creates session query options.

Properties

afterTimestamp double?
Minimum event timestamp (seconds since epoch) to include.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
numRecentEvents int?
Maximum number of most recent events to return.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited