InputValidationError class

Exception indicating invalid user or API input.

Implemented types

Constructors

InputValidationError([String message = 'Invalid input.'])
Creates an input-validation error with optional message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited