ListSessionsResponse class

Response model for session list operations.

Constructors

ListSessionsResponse({List<Session>? sessions})
Creates a session list response.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions List<Session>
Sessions returned by the list query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited