McpJsonRpcException class

Thrown when a JSON-RPC response contains an error object.

Inheritance

Constructors

McpJsonRpcException({required String method, required int? code, required String message})
Creates a JSON-RPC exception for method.

Properties

code int?
The JSON-RPC error code, when provided by the server.
final
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
method String
The JSON-RPC method that failed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited