NodeTimeoutError class

Error thrown when a node exceeds its timeout.

Implemented types

Constructors

NodeTimeoutError({required String nodeName, required Duration timeout})
Creates a node timeout error.

Properties

hashCode int
The hash code for this object.
no setterinherited
nodeName String
Timed-out node name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
Timeout that was exceeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited