RunConfig class

Configuration object controlling one agent run behavior.

Constructors

RunConfig({bool supportCfc = false, StreamingMode streamingMode = StreamingMode.none, ToolExecutionMode toolExecutionMode = ToolExecutionMode.none, int maxLlmCalls = 500, Object? speechConfig, bool saveLiveBlob = false, ToolThreadPoolConfig? toolThreadPoolConfig, List<String>? responseModalities, Object? outputAudioTranscription, Object? inputAudioTranscription, Object? realtimeInputConfig, bool? enableAffectiveDialog, Object? proactivity, Object? sessionResumption, Object? historyConfig, Object? contextWindowCompression, Map<String, dynamic>? customMetadata, GetSessionConfig? getSessionConfig, List<Content>? modelInputContext, bool includeThoughtsFromOtherAgents = false, Map<String, String>? labels})
Creates a run configuration.

Properties

contextWindowCompression Object?
Optional context-window compression configuration.
getter/setter pair
customMetadata Map<String, dynamic>?
Optional custom metadata forwarded with the run.
getter/setter pair
enableAffectiveDialog bool?
Whether affective dialog is enabled.
getter/setter pair
getSessionConfig GetSessionConfig?
Optional filter passed to session-service getSession() calls.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
historyConfig Object?
Optional live history exchange configuration.
getter/setter pair
includeThoughtsFromOtherAgents bool
Whether to include thought parts from other agents when presenting their messages as user context.
getter/setter pair
inputAudioTranscription Object?
Optional input audio transcription config.
getter/setter pair
labels Map<String, String>?
User labels for the current invocation (e.g. for billing/attribution).
getter/setter pair
maxLlmCalls int
Maximum number of model calls allowed in a run.
getter/setter pair
modelInputContext List<Content>?
Transient context to include in the model input for this invocation.
getter/setter pair
outputAudioTranscription Object?
Optional output audio transcription config.
getter/setter pair
proactivity Object?
Optional proactivity configuration.
getter/setter pair
realtimeInputConfig Object?
Optional realtime input configuration.
getter/setter pair
responseModalities List<String>?
Optional requested response modalities.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveLiveBlob bool
Whether live blobs are persisted.
getter/setter pair
sessionResumption Object?
Optional session resumption configuration.
getter/setter pair
speechConfig Object?
Optional speech configuration payload.
getter/setter pair
streamingMode StreamingMode
Streaming behavior for model responses.
getter/setter pair
supportCfc bool
Whether CFC behavior is enabled.
getter/setter pair
toolExecutionMode ToolExecutionMode
Execution behavior for multiple model-requested tool calls.
getter/setter pair
toolThreadPoolConfig ToolThreadPoolConfig?
Optional tool thread-pool configuration.
getter/setter pair

Methods

copyWith({bool? supportCfc, StreamingMode? streamingMode, ToolExecutionMode? toolExecutionMode, int? maxLlmCalls, Object? speechConfig = _sentinel, bool? saveLiveBlob, Object? toolThreadPoolConfig = _sentinel, List<String>? responseModalities, Object? outputAudioTranscription = _sentinel, Object? inputAudioTranscription = _sentinel, Object? realtimeInputConfig = _sentinel, Object? enableAffectiveDialog = _sentinel, Object? proactivity = _sentinel, Object? sessionResumption = _sentinel, Object? historyConfig = _sentinel, Object? contextWindowCompression = _sentinel, Map<String, dynamic>? customMetadata, Object? getSessionConfig = _sentinel, Object? modelInputContext = _sentinel, bool? includeThoughtsFromOtherAgents, Map<String, String>? labels}) RunConfig
Returns a copied run configuration with optional overrides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validateMaxLlmCalls(int value) int
Validates value for maxLlmCalls.