SkillToolset class

Inheritance

Constructors

SkillToolset({required List<Skill> skills, BaseCodeExecutor? codeExecutor, int scriptTimeout = _defaultScriptTimeout})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolFilter Object?
getter/setter pairinherited
toolNamePrefix String?
getter/setter pairinherited

Methods

close() Future<void>
inherited
getAuthConfig() AuthConfig?
Returns auth config for this toolset, if tool listing/calls require auth.
inherited
getTools({ReadonlyContext? readonlyContext}) Future<List<BaseTool>>
override
getToolsWithPrefix({ReadonlyContext? readonlyContext}) Future<List<BaseTool>>
inherited
isToolSelected(BaseTool tool, ReadonlyContext? readonlyContext) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processLlmRequest({required ToolContext toolContext, required LlmRequest llmRequest}) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited