TaskRequest class

A request to delegate work to a task agent.

Constructors

TaskRequest({required String agentName, Map<String, Object?>? input})
Creates a task delegation request.
TaskRequest.fromJson(Map<String, Object?> json)
Creates a request from snake_case or camelCase JSON.
factory

Properties

agentName String
Target agent name.
final
hashCode int
The hash code for this object.
no setterinherited
input Map<String, Object?>
Validated task input data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes this request using Python-compatible snake_case keys.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited