TelemetryLogRecord class

One log entry recorded under a telemetry span.

Constructors

TelemetryLogRecord({required DateTime timestamp, required String message, Map<String, Object?>? attributes})
Creates a span log entry.

Properties

attributes Map<String, Object?>
Structured key-value attributes for this log entry.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable log message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
UTC timestamp when the log entry was produced.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited