WorkflowResult class

Execution result from Workflow.runWorkflow.

Constructors

WorkflowResult({required Map<String, Object?> outputs, required Map<String, NodeState> nodeStates})
Creates workflow result.

Properties

hashCode int
The hash code for this object.
no setterinherited
nodeStates Map<String, NodeState>
Final node states keyed by node name.
final
outputs Map<String, Object?>
Node outputs keyed by node name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited