Skill class

Complete skill representation with metadata, instructions, and resources.

Implemented types

Constructors

Skill({Frontmatter? frontmatter, String? name, String? description, String instructions = '', Resources? resources, String version = '0.1.0', String? license, String? compatibility, String? allowedTools, Map<String, String>? metadata})

Properties

description String
no setteroverride
frontmatter Frontmatter
final
hashCode int
The hash code for this object.
no setterinherited
instructions String
final
name String
no setteroverride
resources Resources
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited