SkillDescriptor class abstract
Minimal shape shared by all skill descriptors.
- Implementers
Constructors
- SkillDescriptor()
- Creates a skill descriptor.
Properties
- description → String
-
Human-readable summary used in skill catalogs.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Stable skill name in lowercase kebab-case.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited