BaseNode class abstract
Base class for node-based workflow units.
- Implementers
Constructors
Properties
-
dependsOn
→ List<
String> -
Names of predecessor nodes that must finish before this node runs.
final
- description → String
-
Human-readable node description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Stable node name.
final
- rerunOnResume → bool
-
Whether the node should rerun after resume.
final
- retryConfig → RetryConfig?
-
Optional retry configuration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
Optional per-attempt timeout.
final
- waitForOutput → bool
-
Whether the workflow should wait for this output before proceeding.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
WorkflowContext context, Object? nodeInput) → FutureOr< Object?> -
Runs this node with
nodeInput. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited