Event class
- Inheritance
-
- Object
- LlmResponse
- Event
Constructors
-
Event({required String invocationId, required String author, EventActions? actions, Set<
String> ? longRunningToolIds, String? branch, String? id, double? timestamp, String? modelVersion, Content? content, bool? partial, bool? turnComplete, String? finishReason, String? errorCode, String? errorMessage, bool? interrupted, Map<String, dynamic> ? customMetadata, Object? usageMetadata, Object? inputTranscription, Object? outputTranscription, double? avgLogprobs, Object? logprobsResult, Object? cacheMetadata, Object? citationMetadata, Object? groundingMetadata, String? interactionId})
Properties
- actions ↔ EventActions
-
getter/setter pair
-
getter/setter pair
- avgLogprobs ↔ double?
-
getter/setter pairinherited
- branch ↔ String?
-
getter/setter pair
- cacheMetadata ↔ Object?
-
getter/setter pairinherited
- citationMetadata ↔ Object?
-
getter/setter pairinherited
- content ↔ Content?
-
getter/setter pairinherited
-
customMetadata
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- errorCode ↔ String?
-
getter/setter pairinherited
- errorMessage ↔ String?
-
getter/setter pairinherited
- finishReason ↔ String?
-
getter/setter pairinherited
- groundingMetadata ↔ Object?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- inputTranscription ↔ Object?
-
getter/setter pairinherited
- interactionId ↔ String?
-
getter/setter pairinherited
- interrupted ↔ bool?
-
getter/setter pairinherited
- invocationId ↔ String
-
getter/setter pair
- logprobsResult ↔ Object?
-
getter/setter pairinherited
-
longRunningToolIds
↔ Set<
String> ? -
getter/setter pair
- modelVersion ↔ String?
-
getter/setter pairinherited
- outputTranscription ↔ Object?
-
getter/setter pairinherited
- partial ↔ bool?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ double
-
getter/setter pair
- turnComplete ↔ bool?
-
getter/setter pairinherited
- usageMetadata ↔ Object?
-
getter/setter pairinherited
Methods
-
copyWith(
{Object? invocationId = _sentinel, Object? author = _sentinel, EventActions? actions, Object? longRunningToolIds = _sentinel, Object? branch = _sentinel, Object? id = _sentinel, Object? timestamp = _sentinel, Object? modelVersion = _sentinel, Object? content = _sentinel, Object? partial = _sentinel, Object? turnComplete = _sentinel, Object? finishReason = _sentinel, Object? errorCode = _sentinel, Object? errorMessage = _sentinel, Object? interrupted = _sentinel, Object? customMetadata = _sentinel, Object? usageMetadata = _sentinel, Object? inputTranscription = _sentinel, Object? outputTranscription = _sentinel, Object? avgLogprobs = _sentinel, Object? logprobsResult = _sentinel, Object? cacheMetadata = _sentinel, Object? citationMetadata = _sentinel, Object? groundingMetadata = _sentinel, Object? interactionId = _sentinel}) → Event -
override
-
getFunctionCalls(
) → List< FunctionCall> -
getFunctionResponses(
) → List< FunctionResponse> -
hasTrailingCodeExecutionResult(
) → bool -
isFinalResponse(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited