EventActions class
Mutable action payload attached to one event.
Constructors
-
EventActions({bool? skipSummarization, Map<
String, Object?> ? stateDelta, Map<String, int> ? artifactDelta, String? transferToAgent, bool? escalate, Map<String, Object> ? requestedAuthConfigs, Map<String, Object> ? requestedToolConfirmations, EventCompaction? compaction, bool? endOfAgent, Map<String, Object?> ? agentState, String? rewindBeforeInvocationId, List<UiWidget> ? renderUiWidgets}) - Creates event actions.
Properties
-
agentState
↔ Map<
String, Object?> ? -
Optional serialized agent state snapshot.
getter/setter pair
-
artifactDelta
↔ Map<
String, int> -
Artifact version deltas produced by the event.
getter/setter pair
- compaction ↔ EventCompaction?
-
Optional compaction metadata.
getter/setter pair
- endOfAgent ↔ bool?
-
Whether this marks the end of the agent run.
getter/setter pair
- escalate ↔ bool?
-
Whether escalation was requested.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
renderUiWidgets
↔ List<
UiWidget> -
UI widgets that the client should render for this event.
getter/setter pair
-
requestedAuthConfigs
↔ Map<
String, Object> -
Requested auth configurations keyed by tool/operation.
getter/setter pair
-
requestedToolConfirmations
↔ Map<
String, Object> -
Requested tool confirmations keyed by tool/operation.
getter/setter pair
- rewindBeforeInvocationId ↔ String?
-
Optional invocation ID to rewind before replay.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipSummarization ↔ bool?
-
Whether this event should be excluded from summarization.
getter/setter pair
-
stateDelta
↔ Map<
String, Object?> -
State updates produced by the event.
getter/setter pair
- transferToAgent ↔ String?
-
Optional target agent name for transfer.
getter/setter pair
Methods
-
copyWith(
{Object? skipSummarization = _sentinel, Map< String, Object?> ? stateDelta, Map<String, int> ? artifactDelta, Object? transferToAgent = _sentinel, Object? escalate = _sentinel, Map<String, Object> ? requestedAuthConfigs, Map<String, Object> ? requestedToolConfirmations, Object? compaction = _sentinel, Object? endOfAgent = _sentinel, Object? agentState = _sentinel, Object? rewindBeforeInvocationId = _sentinel, List<UiWidget> ? renderUiWidgets}) → EventActions - Returns copied actions with optional overrides.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited