EventsCompactionConfig class
Configuration for event compaction behavior.
Constructors
Properties
- compactionInterval ↔ int
-
User-turn interval for sliding-window compaction.
getter/setter pair
- eventRetentionSize ↔ int?
-
Optional number of recent events to retain when compacting.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlapSize ↔ int
-
Number of recent user turns to keep un-compacted.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summarizer ↔ Object?
-
Optional summarizer callback.
getter/setter pair
- tokenThreshold ↔ int?
-
Optional token threshold for token-based compaction.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited