FunctionCallingConfig class
Function-calling configuration attached to tool settings.
Constructors
-
FunctionCallingConfig({FunctionCallingConfigMode mode = FunctionCallingConfigMode.modeUnspecified, List<
String> ? allowedFunctionNames}) - Creates a function-calling configuration.
Properties
-
allowedFunctionNames
↔ List<
String> -
Allowed function names when mode constrains the callable set.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode ↔ FunctionCallingConfigMode
-
Provider mode controlling function-calling behavior.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{FunctionCallingConfigMode? mode, List< String> ? allowedFunctionNames}) → FunctionCallingConfig - Returns a copy of this function-calling configuration.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited