InMemoryArtifactService class
Artifact service backed by process-local memory maps.
- Inheritance
-
- Object
- BaseArtifactService
- InMemoryArtifactService
Constructors
- InMemoryArtifactService()
- Creates an in-memory artifact storage service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteArtifact(
{required String appName, required String userId, required String filename, String? sessionId}) → Future< void> -
Deletes all stored versions for
filenamein memory.override -
getArtifactVersion(
{required String appName, required String userId, required String filename, String? sessionId, int? version}) → Future< ArtifactVersion?> -
Returns metadata for one stored artifact version.
override
-
listArtifactKeys(
{required String appName, required String userId, String? sessionId}) → Future< List< String> > -
Lists artifact keys visible in the user or session scope.
override
-
listArtifactVersions(
{required String appName, required String userId, required String filename, String? sessionId}) → Future< List< ArtifactVersion> > -
Lists metadata snapshots for all versions of
filename.override -
listVersions(
{required String appName, required String userId, required String filename, String? sessionId}) → Future< List< int> > -
Lists stored version numbers for
filename.override -
loadArtifact(
{required String appName, required String userId, required String filename, String? sessionId, int? version}) → Future< Part?> -
Loads one artifact version from memory.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveArtifact(
{required String appName, required String userId, required String filename, required Part artifact, String? sessionId, Map< String, Object?> ? customMetadata}) → Future<int> -
Saves
artifactin memory and returns the next version number.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited