InMemorySkillSource class
In-memory SkillSource implementation.
- Implemented types
Constructors
-
InMemorySkillSource(Map<
String, InMemorySkillData> skills) - Creates a source from pre-built skill data.
-
InMemorySkillSource.fromSkills(Iterable<
Skill> skills) -
Creates a source from complete Skill objects.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listFrontmatters(
) → Future< Map< String, Frontmatter> > -
Lists all available skill frontmatter keyed by skill name.
override
-
listResources(
String skillName, String resourceDirectory) → Future< List< String> > -
Lists resource paths under
resourceDirectory, relative to the skill.override -
loadFrontmatter(
String skillName) → Future< Frontmatter> -
Loads frontmatter for
skillName.override -
loadInstructions(
String skillName) → Future< String> -
Loads the instruction body from
SKILL.mdforskillName.override -
loadResource(
String skillName, String resourcePath) → Future< List< int> > -
Loads one resource as raw bytes, relative to the skill directory.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
builder(
) → InMemorySkillSourceBuilder - Creates a Java-parity builder for in-memory skills.