RequestInput class
Data used to request additional user input from a workflow or agent.
Constructors
- RequestInput({String? interruptId, Object? payload, String? message, Object? responseSchema})
- Creates a request-input payload.
-
RequestInput.fromJson(Map<
String, Object?> json) -
Creates a request-input payload from function-call arguments.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interruptId → String
-
Interrupt identifier used to match the eventual response.
final
- message → String?
-
Optional message shown to the user.
final
- payload → Object?
-
Optional provider-specific payload for the client.
final
- responseSchema → Object?
-
Optional JSON schema describing the expected response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this request into function-call arguments.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited